# education_theses
This repository is for education purpose only. I will upload small-small scripts just for fun. That also helpfull for better understanding of the code as well as packages you probably may not used.